
# Slot: associated environmental context


An attribute that can be applied to an association where the association holds between two entities located or occurring in a particular environment. For example, two microbial taxa may interact in the context of a human gut; a disease may give rise to a particular phenotype in a particular environmental exposure.

URI: [biolink:associated_environmental_context](https://w3id.org/biolink/vocab/associated_environmental_context)


## Domain and Range

[Association](Association.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents

 *  is_a: [association slot](association_slot.md)

## Children

 *  [organism taxon to organism taxon interaction➞associated environmental context](organism_taxon_to_organism_taxon_interaction_associated_environmental_context.md)

## Used by

